/*
 * stat.h - UNIX stat and fstat functions
 *
 * Started 22/11/89 Alex G. Kiernan
 *
 * Copyright (c) 1989 HiSoft
 */

#ifndef _STAT_H
#define	_STAT_H

#ifndef _TIME_T
#define _TIME_T
typedef long time_t;
#endif

struct stat
{
	dev_t st_dev;			/* device */
	ino_t st_ino;			/* inode number - not used */
	unsigned short st_mode;	/* mode */
	short st_nlink;			/* number of links == 1 */
	short st_uid;			/* user id == pid */
	short st_gid;			/* group id == pid */
	dev_t st_rdev;			/* real device */
	off_t st_size;			/* file size */
	time_t st_atime;		/* access time */
	time_t st_mtime;		/* modified time */
	time_t st_ctime;		/* changed time */
};

#define S_IJRON	0x01		/* read only */
#define S_IJHID	0x02		/* hidden */
#define S_IJSYS	0x04		/* system */
#define S_IJVOL	0x08		/* label */
#define S_IJDIR	0x10		/* directory */
#define S_IJWAC	0x20		/* archive */

typedef struct
{
	char d_resvd[21];
	char d_fattr;		/* File attributes */
	long d_tandd;		/* Time and date words */
	long d_fsize;		/* File size */
	char d_fname[14];	/* File name */
} DMABUFFER;

#define S_IFMT	0170000
#define S_IFDIR	0040000
#define S_IFCHR	0020000
#define S_IFREG	0100000

#define S_IREAD	0000400
#define S_IWRITE	0000200
#define S_IEXEC	0000100

#define S_IRWXU	00700		/* read, write, execute - user */
#define S_IRUSR	00400		/* read permission - user */
#define S_IWUSR	00200		/* write permission - user */
#define S_IXUSR	00100		/* execute permission - user */

#define S_IRWXG	00070		/* read, write, execute - group */
#define S_IRGRP	00040		/* read permission - group */
#define S_IWGRP	00020		/* write permission - group */
#define S_IXGRP	00010		/* execute permission - group */

#define S_IRWXO	00007		/* read, write, execute - other */
#define S_IROTH	00004		/* read permission - other */
#define S_IWOTH	00002		/* write permission - other */
#define S_IXOTH	00001		/* execute permission - other */

int fstat(int, struct stat *);
int stat(const char *, struct stat *);

#endif
